
#ifndef __PREFERENCE_H__
#define __PREFERENCE_H__

#include "defs.h"

#define FILENAME_DICTIONARIES   "dictionaries.xml"
#define FILENAME_PREFERENCES    "preferences.xml"
#define FILENAME_HOTKEYS	"hotkeys.xml"
#define FILENAME_HISTORY        "history.xml"

void            preferences_init();
void            preferences_load();
void            preferences_show();
void            preferences_save();
void		preferences_close_wnd();
void            preferences_show_cb(GtkWidget *w, gpointer data);

struct _pref
{
    gchar       *user, *codeset;
    GtkWidget   *dlg, *note;
    GNode       *dicts;
} pref;

struct _preferences
{
    gchar *name;
    gint type;
    void *addr;
};

#endif /* __PREFERENCE_H__ */
